summaryrefslogtreecommitdiff
path: root/OvmfPkg/PlatformPei
diff options
context:
space:
mode:
authorGabriel Somlo <somlo@cmu.edu>2014-11-14 00:37:39 +0000
committerjljusten <jljusten@Edk2>2014-11-14 00:37:39 +0000
commitd55004dac9c762fa01c5656f7a2e6132ed7bfe38 (patch)
treeafcfd701801ba502072c80477bd8ad4238149533 /OvmfPkg/PlatformPei
parent97380beb15249f6abf4250ccccbae0f740649985 (diff)
downloadedk2-platforms-d55004dac9c762fa01c5656f7a2e6132ed7bfe38.tar.xz
OvmfPkg: Add PCD for Host Bridge dev. ID (PcdOvmfHostBridgePciDevId)
Set from PEI, this PCD allows subsequent stages (specifically DXE_DRIVER and DXE_RUNTIME_DRIVER) to infer the underlying platform type (e.g. PIIX4 or Q35/MCH) without the need to further query the Host Bridge for its Device ID. Contributed-under: TianoCore Contribution Agreement 1.0 Signed-off-by: Gabriel Somlo <somlo@cmu.edu> Reviewed-by: Paolo Bonzini <pbonzini@redhat.com> Reviewed-by: Jordan Justen <jordan.l.justen@intel.com> Reviewed-by: Gerd Hoffmann <kraxel@redhat.com> Reviewed-by: Laszlo Ersek <lersek@redhat.com> git-svn-id: https://svn.code.sf.net/p/edk2/code/trunk/edk2@16374 6f19259b-4bc3-4df7-8a09-765794883524
Diffstat (limited to 'OvmfPkg/PlatformPei')
-rw-r--r--OvmfPkg/PlatformPei/Platform.c3
-rw-r--r--OvmfPkg/PlatformPei/PlatformPei.inf1
2 files changed, 3 insertions, 1 deletions
diff --git a/OvmfPkg/PlatformPei/PlatformPei.inf b/OvmfPkg/PlatformPei/PlatformPei.inf
index a5fa9b5004..0307bca913 100644
--- a/OvmfPkg/PlatformPei/PlatformPei.inf
+++ b/OvmfPkg/PlatformPei/PlatformPei.inf
@@ -73,6 +73,7 @@
gUefiOvmfPkgTokenSpaceGuid.PcdOvmfLockBoxStorageBase
gUefiOvmfPkgTokenSpaceGuid.PcdOvmfLockBoxStorageSize
gUefiOvmfPkgTokenSpaceGuid.PcdGuidedExtractHandlerTableSize
+ gUefiOvmfPkgTokenSpaceGuid.PcdOvmfHostBridgePciDevId
gEfiIntelFrameworkModulePkgTokenSpaceGuid.PcdS3AcpiReservedMemorySize
gEfiMdePkgTokenSpaceGuid.PcdGuidedExtractHandlerTableAddress
gEfiMdeModulePkgTokenSpaceGuid.PcdVariableStoreSize
diff --git a/OvmfPkg/PlatformPei/Platform.c b/OvmfPkg/PlatformPei/Platform.c
index d8a7c21ae0..1940e01640 100644
--- a/OvmfPkg/PlatformPei/Platform.c
+++ b/OvmfPkg/PlatformPei/Platform.c
@@ -245,7 +245,7 @@ MiscInitialization (
BuildCpuHob (36, 16);
//
// Query Host Bridge DID to determine platform type
//
HostBridgeDevId = PciRead16 (OVMF_HOSTBRIDGE_DID);
switch (HostBridgeDevId) {
@@ -265,6 +265,7 @@ MiscInitialization (
ASSERT (FALSE);
return;
}
+ PcdSet16 (PcdOvmfHostBridgePciDevId, HostBridgeDevId);
//
// If PMREGMISC/PMIOSE is set, assume the ACPI PMBA has been configured (for
@@ -245,7 +245,7 @@ MiscInitialization (
BuildCpuHob (36, 16);
//
- // Query Host Bridge DID to determine platform type
+ // Query Host Bridge DID to determine platform type and save to PCD
//
HostBridgeDevId = PciRead16 (OVMF_HOSTBRIDGE_DID);